Pandora
=======

.. image:: https://travis-ci.org/frootlab/pandb.svg?branch=master
   :target: https://travis-ci.org/frootlab/pandb

.. image:: https://readthedocs.org/projects/pandora/badge/?version=latest
    :target: https://pandora.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://badge.fury.io/py/pandb.svg
    :target: https://badge.fury.io/py/pandb

*Pandora* is a SQL database engine and a universal database proxy. Pandora aims
to provide a unified SQL:2016 interface to a broad variety of different data
sources, including SQL Databases and flat files from laboratory measurements.
Pandora is open source and based on the `Python`_ programming language.

- **Documentation**: https://pandora.readthedocs.io
- **Issues**: https://github.com/frootlab/pandb/issues
- **Source**: https://github.com/frootlab/pandb

Install
-------

Install the latest version of pandora::

    $ pip install pandb

Contribute
----------

Contributors are very welcome! Feel free to report bugs and feature requests to
the `issue tracker`_ provided by GitHub.

License
-------

Pandora is available free for any use under the `GPLv3 license`_::

   Copyright (c) 2019 Pandora Developers
   Patrick Michl <patrick.michl@gmail.com>

.. _Python: https://www.python.org/
.. _GPLv3 license: https://www.gnu.org/licenses/gpl.html
.. _issue tracker: https://github.com/frootlab/pandora/issues
.. _frootlab: https://github.com/frootlab
